@@ -1,18 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** Licensed under the Apache License, Version 2.0 (the "License");
-** you may not use this file except in compliance with the License.
-** You may obtain a copy of the License at
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-**     http://www.apache.org/licenses/LICENSE-2.0
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** Unless required by applicable law or agreed to in writing, software
-** distributed under the License is distributed on an "AS IS" BASIS,
-** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-** See the License for the specific language governing permissions and
-** limitations under the License.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package dbconn
@@ -144,6 +141,7 @@ func TestConnCollection_Init(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -157,9 +155,7 @@ func TestConnCollection_Init(t *testing.T) {
 			c.Init(tt.args.keepAlive, tt.args.queryTimetout, tt.args.logr)
 
 			if diff := cmp.Diff(
-				tt.want, c,
-				cmp.AllowUnexported(ConnCollection{}, sync.Mutex{}),
-				cmpopts.IgnoreFields(ConnCollection{}, "mu"),
+				tt.want, c, cmp.AllowUnexported(ConnCollection{}, sync.Mutex{}),
 			); diff != "" {
 				t.Fatalf("ConnCollection.Init() = %s", diff)
 			}
@@ -467,6 +463,7 @@ func TestConnCollection_Close(t *testing.T) {
 		{"-closeErr", fields{errors.New("fail")}},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) { //nolint:paralleltest
 			t.Parallel()
 
@@ -677,11 +674,9 @@ func TestConnCollection_get(t *testing.T) {
 					},
 				),
 				cmpopts.IgnoreFields(ConnCollection{}, "logr"),
-				cmpopts.IgnoreFields(ConnCollection{}, "mu"),
 			); diff != "" {
 				t.Fatalf("ConnCollection.get() = %s", diff)
 			}
-
 			if m != nil {
 				if err := m.ExpectationsWereMet(); err != nil {
 					t.Fatalf("ConnCollection.get() = %s", err.Error())
@@ -738,38 +733,6 @@ func TestConnCollection_newConn(t *testing.T) {
 			false,
 			false,
 		},
-		{
-			"+named",
-			expect{true, true},
-			fields{
-				keepAlive:  4,
-				dsn:        "pigeon://aaaa:bbbb@uri/InstanceName?app+name=Zabbix+agent+2+MSSQL+plugin&keepAlive=4",
-				driverName: "testdriver",
-			},
-			args{&connConfig{
-				User:     "aaaa",
-				Password: "bbbb",
-				URI:      "pigeon://uri/InstanceName",
-			}},
-			false,
-			false,
-		},
-		{
-			"+namedWithPort",
-			expect{true, true},
-			fields{
-				keepAlive:  4,
-				dsn:        "pigeon://aaaa:bbbb@uri:1435/InstanceName?app+name=Zabbix+agent+2+MSSQL+plugin&keepAlive=4",
-				driverName: "testdriver",
-			},
-			args{&connConfig{
-				User:     "aaaa",
-				Password: "bbbb",
-				URI:      "pigeon://uri:1435/InstanceName",
-			}},
-			false,
-			false,
-		},
 		{
 			"+validWithTLS",
 			expect{true, true},
@@ -778,7 +741,7 @@ func TestConnCollection_newConn(t *testing.T) {
 				dsn: "pigeon://aaaa:bbbb@uri:1433?" +
 					"TrustServerCertificate=false&" +
 					"app+name=Zabbix+agent+2+MSSQL+plugin&" +
-					"certificate=abc&" +
+					"certificate=%2Fa%2Fb%2Fc&" +
 					"encrypt=true&" +
 					"hostNameInCertificate=server&" +
 					"keepAlive=4&" +
@@ -789,7 +752,7 @@ func TestConnCollection_newConn(t *testing.T) {
 				User:                   "aaaa",
 				Password:               "bbbb",
 				URI:                    "pigeon://uri",
-				CACertPath:             "abc",
+				CACertPath:             "/a/b/c",
 				TrustServerCertificate: "false",
 				HostNameInCertificate:  "server",
 				Encrypt:                "true",
@@ -884,14 +847,12 @@ func TestConnCollection_newConn(t *testing.T) {
 						err, tt.wantErr,
 					)
 				}
-
 				if (got == nil) != tt.wantNil {
 					t.Fatalf(
 						"ConnCollection.newConn() got = %v, wantNil %v",
 						got, tt.wantNil,
 					)
 				}
-
 				if m != nil {
 					if err := m.ExpectationsWereMet(); err != nil {
 						t.Fatalf(
@@ -947,6 +908,7 @@ func Test_newConnConfig(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
